# Waylon Walker cli

My personal business card.

``` bash
pipx run waylonwalker
# alternatively with docker
docker run -it --rm docker.io/waylonwalker/waylonwalker:latest
```

https://github.com/WaylonWalker/waylonwalker-cli/assets/22648375/a534a740-9f54-4788-acc4-96a42ac3d7ba

